#!BPY

""" Registration info for Blender menus:
Name: 'LDraw colors...'
Blender: 233
Group: 'Import'
Tip: 'Import LDraw colors (ldconfig.ldr) file.'
"""

import Blender
import string

#0 !COLOUR Light_Violet      CODE  20  VALUE #D7C4E6  EDGE 22
#0 !COLOUR Phosphor_White    CODE  21  VALUE #E0FFB0  EDGE #77CC00  ALPHA 250  LUMINANCE 15
#0 !COLOUR Pearl_Sand_Blue   CODE 137  VALUE #6A7A96  EDGE 1        PEARLESCENT
#0 !COLOUR Rubber_Black      CODE 256  VALUE #212121  EDGE #000000  RUBBER
#0 !COLOUR Chrome_Gold       CODE 334  VALUE #E16E13  EDGE 12       CHROME

#The entire statement must appear on one line. It may be line-wrapped in this document for clarity.

#0 !COLOUR name CODE x VALUE v EDGE e [ALPHA a] [LUMINANCE l] [CHROME | PEARLESCENT | RUBBER | MATTE_METALLIC | METAL | MATERIAL name <params> </params>]

# CODE, VALUE, EDGE, ALPHA, DITHER, LUMINANCE, CHROME, PEARLESCENT, RUBBER, MATTE_METALLIC, METAL and MATERIAL are keyword tags. Some tags are followed by a single parameter value. Tags are case-insensitive. Numeric parameters, other than RGB color values, should be specified in decimal. RGB values must be specified in hexidecimal, and must be prefixed with # or 0x. Byte values are integers in the range 0-255. Identifiers are strings of text. The allowable characters are alphanumerics from 7-bit ASCII set: a-zA-Z0-9_. Additionally, the first character in an identifier must an alphabetic (a-zA-Z). Identifiers are case-insensitive.

class ImporterOptions:
  def __init__(self):
    self.defaults = {'ColorProfile': "~/.blender/scripts/ldconfig.ldr"}
    d = Blender.Registry.GetKey('ldc_import',True)
    
    if d == None or d.keys() != self.defaults.keys():
      d = self.defaults
      Blender.Registry.SetKey('ldc_import',d,True)
    self.get_colorprofile = d['ColorProfile']


class ColorImporter:
  def __init__(self):
    print "--- ColorImporter ---"
 
  def importColors(self):
    options = ImporterOptions();
    from Blender.Window import FileSelector
    print "File:", options.get_colorprofile
    loadcolors(options.get_colorprofile)

    
def loadcolors(filename):
  try:
    text=Blender.Text.Get("LDrawMaterials")
    Blender.Text.unlink(text)
  except:
    print ""
  text=Blender.Text.New("LDrawMaterials")
  mat_replaced=0
  mat_new=0
  unknown=[]
  print "Materiau non connu :"
  for line in file(filename):
    words=line.split()
    print words
    if words[0:2]==['0','!COLOUR']:
      name=words[2]
      number=words[4]
      try:
        mat=Blender.Material.Get(name)
        mat_replaced += 1
        print "deja presents :", name
      except:
        mat=Blender.Material.New(name)
        mat_new += 1
        print "nouveau :", name
      r=float (string.atoi (words[6][1:3],16)) / 255
      g=float (string.atoi (words[6][3:5],16)) / 255
      b=float (string.atoi (words[6][5:7],16)) / 255
      mat.rgbCol=[r,g,b]
      # plastic
      #mat.ref=0.25 un peu sombre a mon gout
      #mat.ref=0.55 semble etre un bon compromis
      mat.ref=0.55
      i = 9
      while i < len(words):
        if words[i]=='ALPHA':
          mat.alpha=float(words[i+1])/255
          i = i + 2
          if mat.alpha<1:
            mat.mode|=Blender.Material.Modes['ZTRANSP']
        elif words[i]=='LUMINANCE':
          mat.emit=float(words[i+1])/255
          i = i + 2
        elif words[i]=='CHROME':
          mat.ref=1
          i = i + 1
        else:
          # CHROME | PEARLESCENT | RUBBER | MATTE_METALLIC | METAL
          if unknown.count(words[i]) <= 0:
            print words[i]
            unknown.append(words[i])
          i = i + 1
      text.write('%s %s\n'%(number, name))
  print "-------------------------"
  print "remplacement:", mat_replaced
  print "nouveau:", mat_new
  print "-------------------------"

imp = ColorImporter()
imp.importColors();

#if __name__ == '__main__':
#  from Blender.Window import FileSelector
#  FileSelector(loadcolors)

